@@ -26,9 +26,7 @@ fn stop_containers(container_id: &str) {
         .arg("stop")
         .arg(container_id)
         .spawn()
-        .unwrap()
-        .wait()
-        .expect("failed to execute docker stop");
+        .unwrap();
 }
 
 fn remove_containers(container_id: &str) {
@@ -36,9 +34,7 @@ fn remove_containers(container_id: &str) {
         .arg("rm")
         .arg(container_id)
         .spawn()
-        .unwrap()
-        .wait()
-        .expect("failed to execute docker rm");
+        .unwrap();
 }
 
 fn stop_and_remove_container(image: String) {
@@ -99,7 +95,7 @@ fn simple_build(path: &str) -> String {
         Vec::new(),
         None,
         None,
-        false,
+        true,
         Vec::new(),
         None,
         None,
@@ -121,7 +117,14 @@ fn test_node() {
 fn test_node_custom_version() {
     let name = simple_build("./examples/node-custom-version");
     let output = run_image(name);
-    assert!(output.contains("Node version: v12"));
+    assert!(output.contains("Node version: v14"));
+}
+
+#[test]
+fn test_node_no_lockfile() {
+    let name = simple_build("./examples/node-no-lockfile");
+    let output = run_image(name);
+    assert!(output.contains("Hello from Node"));
 }
 
 #[test]
@@ -131,6 +134,13 @@ fn test_yarn_custom_version() {
     assert!(output.contains("Node version: v14"));
 }
 
+#[test]
+fn test_yarn_berry() {
+    let name = simple_build("./examples/yarn-berry");
+    let output = run_image(name);
+    assert!(output.contains("Hello from Yarn v2+"));
+}
+
 #[test]
 fn test_yarn_prisma() {
     let name = simple_build("./examples/yarn-prisma");
@@ -138,6 +148,20 @@ fn test_yarn_prisma() {
     assert!(output.contains("My post content"));
 }
 
+#[test]
+fn test_pnpm() {
+    let name = simple_build("./examples/pnpm");
+    let output = run_image(name);
+    assert!(output.contains("Hello from PNPM"));
+}
+
+#[test]
+fn test_pnpm_custom_version() {
+    let name = simple_build("./examples/pnpm-custom-node-version");
+    let output = run_image(name);
+    assert!(output.contains("Hello from PNPM"));
+}
+
 #[test]
 fn test_python() {
     let name = simple_build("./examples/python");
@@ -152,13 +176,6 @@ fn test_python_2() {
     assert!(output.contains("Hello from Python 2"));
 }
 
-#[test]
-fn test_deno() {
-    let name = simple_build("./examples/deno");
-    let output = run_image(name);
-    assert!(output.contains("Hello Deno"));
-}
-
 #[test]
 fn test_rust_custom_version() {
     let name = simple_build("./examples/rust-custom-version");
@@ -173,6 +190,13 @@ fn test_go() {
     assert!(output.contains("Hello from Go"));
 }
 
+#[test]
+fn test_haskell_stack() {
+    let name = simple_build("./examples/haskell-stack");
+    let output = run_image(name);
+    assert!(output.contains("Hello from Haskell"));
+}
+
 #[test]
 fn test_cowsay() {
     let name = Uuid::new_v4().to_string();
