@@ -4,6 +4,24 @@ use nixpacks::{gen_plan, nixpacks::nix::Pkg};
 #[test]
 fn test_node() -> Result<()> {
     let plan = gen_plan("./examples/node", Vec::new(), None, None, Vec::new(), false)?;
+    assert_eq!(plan.install.unwrap().cmd, Some("npm ci".to_string()));
+    assert_eq!(plan.build.unwrap().cmd, None);
+    assert_eq!(plan.start.unwrap().cmd, Some("npm run start".to_string()));
+
+    Ok(())
+}
+
+#[test]
+fn test_node_no_lockfile() -> Result<()> {
+    let plan = gen_plan(
+        "./examples/node-no-lockfile",
+        Vec::new(),
+        None,
+        None,
+        Vec::new(),
+        false,
+    )?;
+    assert_eq!(plan.install.unwrap().cmd, Some("npm i".to_string()));
     assert_eq!(plan.build.unwrap().cmd, None);
     assert_eq!(plan.start.unwrap().cmd, Some("npm run start".to_string()));
 
@@ -53,7 +71,7 @@ fn test_node_custom_version() -> Result<()> {
         Vec::new(),
         false,
     )?;
-    assert_eq!(plan.setup.unwrap().pkgs, vec![Pkg::new("nodejs-12_x")]);
+    assert_eq!(plan.setup.unwrap().pkgs, vec![Pkg::new("nodejs-14_x")]);
 
     Ok(())
 }
@@ -61,8 +79,8 @@ fn test_node_custom_version() -> Result<()> {
 #[test]
 fn test_yarn() -> Result<()> {
     let plan = gen_plan("./examples/yarn", Vec::new(), None, None, Vec::new(), false)?;
-    assert_eq!(plan.build.unwrap().cmd, Some("yarn build".to_string()));
-    assert_eq!(plan.start.unwrap().cmd, Some("yarn start".to_string()));
+    assert_eq!(plan.build.unwrap().cmd, Some("yarn run build".to_string()));
+    assert_eq!(plan.start.unwrap().cmd, Some("yarn run start".to_string()));
     assert_eq!(
         plan.variables.clone().unwrap().get("NODE_ENV"),
         Some(&"production".to_string())
@@ -75,6 +93,23 @@ fn test_yarn() -> Result<()> {
     Ok(())
 }
 
+#[test]
+fn test_yarn_berry() -> Result<()> {
+    let plan = gen_plan(
+        "./examples/yarn-berry",
+        Vec::new(),
+        None,
+        None,
+        Vec::new(),
+        false,
+    )?;
+    assert_eq!(
+        plan.install.unwrap().cmd,
+        Some("yarn set version berry && yarn install --immutable --check-cache".to_string())
+    );
+    Ok(())
+}
+
 #[test]
 fn test_yarn_custom_version() -> Result<()> {
     let plan = gen_plan(
@@ -96,6 +131,44 @@ fn test_yarn_custom_version() -> Result<()> {
     Ok(())
 }
 
+#[test]
+fn pnpm() -> Result<()> {
+    let plan = gen_plan("./examples/pnpm", Vec::new(), None, None, Vec::new(), false)?;
+    assert_eq!(plan.build.unwrap().cmd, Some("pnpm run build".to_string()));
+    assert_eq!(plan.start.unwrap().cmd, Some("pnpm run start".to_string()));
+    assert_eq!(
+        plan.variables.clone().unwrap().get("NODE_ENV"),
+        Some(&"production".to_string())
+    );
+    assert_eq!(
+        plan.variables.unwrap().get("NPM_CONFIG_PRODUCTION"),
+        Some(&"false".to_string())
+    );
+
+    Ok(())
+}
+
+#[test]
+fn test_pnpm_custom_version() -> Result<()> {
+    let plan = gen_plan(
+        "./examples/pnpm-custom-node-version",
+        Vec::new(),
+        None,
+        None,
+        Vec::new(),
+        false,
+    )?;
+    assert_eq!(
+        plan.setup.unwrap().pkgs,
+        vec![
+            Pkg::new("nodejs-14_x"),
+            Pkg::new("nodePackages.pnpm").set_override("nodejs", "nodejs-14_x")
+        ]
+    );
+
+    Ok(())
+}
+
 #[test]
 fn test_go() -> Result<()> {
     let plan = gen_plan("./examples/go", Vec::new(), None, None, Vec::new(), false)?;
@@ -351,3 +424,19 @@ fn test_config_from_environment_variables() -> Result<()> {
 
     Ok(())
 }
+
+#[test]
+fn test_haskell_stack() -> Result<()> {
+    let plan = gen_plan(
+        "./examples/haskell-stack",
+        Vec::new(),
+        None,
+        None,
+        Vec::new(),
+        false,
+    )?;
+    assert_eq!(plan.build.unwrap().cmd, Some("stack build".to_string()));
+    assert!(plan.start.unwrap().cmd.unwrap().contains("stack exec"));
+    assert!(plan.install.unwrap().cmd.unwrap().contains("stack setup"));
+    Ok(())
+}
